ListConfig<T> class

Inheritance

Constructors

ListConfig({required LoadingMoreItemBuilder<T> itemBuilder, required LoadingMoreBase<T> sourceList, bool showGlowLeading = true, bool showGlowTrailing = true, LoadingMoreIndicatorBuilder? indicatorBuilder, SliverGridDelegate? gridDelegate, Axis scrollDirection = Axis.vertical, bool reverse = false, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool shrinkWrap = false, EdgeInsetsGeometry padding = const EdgeInsets.all(0.0), double? itemExtent, int? itemCount, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, double? cacheExtent, int? semanticChildCount, bool autoLoadMore = true, ExtendedListDelegate? extendedListDelegate, LastChildLayoutType lastChildLayoutType = LastChildLayoutType.foot, bool autoRefresh = true, int itemCountBuilder(int count)?, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, String? restorationId, Clip clipBehavior = Clip.hardEdge, int getActualIndex(int count)?})
const

Properties

addAutomaticKeepAlives → bool
Whether to wrap each child in an AutomaticKeepAlive.
final
addRepaintBoundaries → bool
Whether to wrap each child in a RepaintBoundary.
final
addSemanticIndexes → bool
Whether to wrap each child in an IndexedSemantics.
final
autoLoadMore → bool
Whether to auto load more with the sourceList.
finalinherited
autoRefresh → bool
Whether to auto refresh with the sourceList.
finalinherited
cacheExtent → double?
final
childCount → int?
The total number of children this delegate can provide.
finalinherited
childCountBuilder → int Function(int count)?
The builder to get child count,the input is LoadingMoreBase.length.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
controller → ScrollController?
An object that can be used to control the position to which this scroll view is scrolled.
final
dragStartBehavior → DragStartBehavior
Configuration of offset passed to DragStartDetails.
final
extendedListDelegate → ExtendedListDelegate?
The delegate for WaterfallFlow or ExtendedList.
finalinherited
getActualIndex → int Function(int count)?
finalinherited
gridDelegate → SliverGridDelegate?
Set the gridDelegate if the config is for a grid view.
finalinherited
hasError → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
no setterinherited
indicatorBuilder → LoadingMoreIndicatorBuilder?
The builder for each IndicatorStatus.
finalinherited
isLoading → bool
no setterinherited
isSliver → bool
no setterinherited
itemBuilder → LoadingMoreItemBuilder<T>
Builds widget from item and index.
finalinherited
itemExtent → double?
If non-null, forces the children to have the given extent in the scroll direction.
final
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
ScrollViewKeyboardDismissBehavior the defines how this ScrollView will dismiss the keyboard automatically.
final
lastChildLayoutType → LastChildLayoutType
Layout type of last child.
finalinherited
padding → EdgeInsetsGeometry
The amount of space by which to inset the children.
final
physics → ScrollPhysics?
How the scroll view should respond to user input.
final
primary → bool?
Whether this is the primary scroll view associated with the parent PrimaryScrollController.
final
restorationId → String?
Restoration ID to save and restore the scroll offset of the scrollable.
final
reverse → bool
Whether the scroll view scrolls in the reading direction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
The axis along which the scroll view scrolls.
final
semanticChildCount → int?
The number of children that will contribute semantic information.
final
showGlowLeading → bool
Whether to show the overscroll glow on the side with negative scroll offsets.
final
showGlowTrailing → bool
Whether to show the overscroll glow on the side with positive scroll offsets.
final
shrinkWrap → bool
Whether the extent of the scroll view in the scrollDirection should be determined by the contents being viewed.
final
sourceList → LoadingMoreBase<T>
Source list based on the LoadingMoreBase.
finalinherited
useProviderValue → bool
finalinherited

Methods

buildContent(BuildContext context, LoadingMoreBase<T>? source) → Widget
override
buildErrorItem(BuildContext context) → Widget?
inherited
buildItem(BuildContext context, int index) → Widget
inherited
getExtendedListDelegate(int childCount, {bool showNoMore = true}) → ExtendedListDelegate
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited